-- formatter
require('formatter').setup {
  logging = false,
  filetype = {
    bib = {
      function()
        return {
          exe = "bibclean",
          args = {"-align-equals"},
          stdin = true
        }
      end
    },
    rust = {
      function()
        return {
          exe = "rustfmt",
          args = {"--emit=stdout"},
          stdin = true
        }
      end
    },
    python = {
      function()
        return {
          exe = "black",
          args = {"--quiet", "-"},
          stdin = true
        }
      end,
      function()
        return {
          exe = "isort",
          args = {"--quiet", "-"},
          stdin = true
        }
      end
    },
    haskell = {
      function()
        return {
          exe = "ormolu",
          args = {"-"},
          stdin = true
        }
      end
    },
    c = {
      function()
        return {
          exe = "clang-format",
          args = {},
          stdin = true,
          cwd = vim.fn.expand('%:p:h')
        }
      end
    },
    cpp = {
      function()
        return {
          exe = "clang-format",
          args = {},
          stdin = true,
          cwd = vim.fn.expand('%:p:h')
        }
      end
    },
    clojure = {
      function()
        return {
          exe = "zprint",
          args = {"-w", vim.api.nvim_buf_get_name(0)},
          stdin = false,
        }
      end
    },
    javascript = {
      function()
        return {
          exe = "prettier",
          args = {"--stdin-filepath", vim.api.nvim_buf_get_name(0), '--single-quote'},
          stdin = true
        }
      end
    },
    r = {
      function()
        return {
          exe = "R",
          args = {
            "--slave",
            "--no-restore",
            "--no-save",
            "-e",
            '\'con <- file("stdin"); styler::style_text(readLines(con)); close(con)\'',
            "2>/dev/null"
          },
          stdin = true
        }
      end
    },
    sh = {
      function()
        return {
          exe = "shfmt",
          args = { "-i", 2 },
          stdin = true,
        }
      end,
    }
  }
}

vim.api.nvim_exec([[
augroup formatters
  autocmd!
  autocmd BufWritePost *.bib,*.clj,*.R,*.r,*.sh,*.js,*.hs,*.py,*.cpp,*.c,*.rs FormatWrite
augroup END
]], true)
