local utils = require "utils"

local scopes = {o = vim.o, b = vim.bo, w = vim.wo}

local indent, width = 2, 80
utils.opt("b", "expandtab", true)                     -- use spaces instead of tabs
utils.opt("b", "formatoptions", "crqnj")              -- automatic formatting options
utils.opt("b", "shiftwidth", indent)                  -- size of an indent
utils.opt("b", "textwidth", width)                    -- maximum width of text
utils.opt("b", "tabstop", indent)                     -- number of spaces tabs count for
utils.opt("b", 'smartindent', true)                   -- insert indents automatically

utils.opt("w", "list", false)                         -- do not show invisible characters by default
utils.opt("w", "signcolumn", "yes")                   -- show sign column
utils.opt("w", "number", true)                        -- show line numbers
utils.opt("w", "relativenumber", false)               -- show relative line numbers

utils.opt("o", "clipboard", "unnamedplus")            -- use system copy/paste
utils.opt("o", "hlsearch", true)                      -- highlight search results
utils.opt("o", "incsearch", true)                     -- show search matches as you type
utils.opt("o", "inccommand", "nosplit")               -- disable preview for :substitute
utils.opt("o", "ignorecase", true)                    -- ignore case
utils.opt("o", "smartcase", true)                     -- ignore case if search pattern is lowercase
utils.opt("o", "hidden", true)                        -- enable modified buffers in background
utils.opt("o", "joinspaces", false)                   -- no double spaces with join after a dot
utils.opt("o", "shiftround", true)                    -- move in multiples of shiftwidth with < and >
utils.opt("o", "splitbelow", true)                    -- horizontal split direction
utils.opt("o", "splitright", true)                    -- vertical split direction
utils.opt("o", "termguicolors", true)                 -- true color support
utils.opt("o", "updatetime", 300)                     -- timer (swap + LSP stuff)
utils.opt('o', "wildmode", "list:longest")            -- command-line completion mode
utils.opt('o', "mouse", "a")                          -- allow mouse actions

vim.cmd[[set listchars=tab:▸\ ,eol:¬,trail:·]]        -- textmate-style tabstops/EOLs
vim.cmd[[set iskeyword+=-]]                           -- Lisp/Scheme/Bibtex
vim.cmd[[set wildignore+=*swp,*.class,*.pyc,*.o,*.obj,*.so]]

vim.cmd[[set undofile]]
vim.cmd[[set undodir=~/.local/share/nvim/undo/]]      -- undo dir
vim.cmd[[set backupdir=~/.local/share/nvim/backup/]]  -- backup dir
vim.cmd[[set directory=~/.local/share/nvim/swap/]]    -- swap dir

-- augroup settings
vim.api.nvim_exec([[
augroup term
  autocmd!
  autocmd TermOpen * tnoremap <Esc> <C-\><C-n>
augroup END
augroup ftdetect
  autocmd!
  autocmd BufRead,BufNewFile *.rkt,*.rktl set filetype=racket
  autocmd BufReadPost,BufNewFile *.rmd,*.Rmd set filetype=markdown
  autocmd BufRead,BufNewFile *.m,*.nb set filetype=mma
augroup END
augroup spell
  autocmd!
  autocmd BufRead,BufNewFile *.md,*.org setlocal spell
  autocmd FileType gitcommit setlocal spell
augroup END
augroup whitespace
  autocmd!
  " autocmd BufEnter * if &ft != 'help' | match ExtraWhitespace /\s\+$/ | endif
  autocmd BufWritePre * %s/\s\+$//e
augroup END
augroup cursorPos
  autocmd!
  autocmd BufReadPost * if line("'\"") > 1 && line("'\"") <= line("$") | exe "normal! g`\"" | endif
augroup END
" augroup highlightYank
"   autocmd!
"   autocmd TextYankPost * silent! lua require'vim.highlight'.on_yank()
" augroup END
]], true)

-- misc settings
vim.cmd[[set grepprg=rg\ --vimgrep]]
vim.cmd[[set grepformat^=%f:%l:%c:%m]]

vim.cmd[[let g:loaded_perl_provider = 0]]
vim.cmd[[let g:loaded_python_provider = 0]]
vim.cmd[[let g:python3_host_prog = '/usr/bin/python3']]
vim.cmd[[let g:netrw_banner = 0]]

vim.cmd[[command -complete=dir -nargs=+ Grep silent grep <args> | redraw!]]
vim.cmd[[command! -nargs=? -range Align <line1>,<line2>call text#align_section('<args>')]]
vim.cmd[[command! Bibopen call text#open_bibtex_key()]]
vim.cmd[[command! -range Gist call system('gist', getbufline('%', <line1>, <line2>))]]
vim.cmd[[command! -range=% Htmlize call system('cat|pandoc -s -f markdown -o ~/tmp/out.html && xdg-open ~/tmp/out.html', getbufline('%', <line1>, <line2>))]]
vim.cmd[[command! Changelog execute "normal i<C-R>=strftime('%Y-%m-%d')<CR><ESC>$a chl <chl@aliquote.org> -"]]

vim.cmd[[iabbrev +%< -%<----<CR><CR>---->%-]]
vim.cmd[[iabbrev +'' ```<CR><CR>```]]
vim.cmd[[iabbrev +:: ¯\_(ツ)_/¯]]
vim.cmd[[iabbrev +:( ಠ_ಠ]]
vim.cmd[[iabbrev +:) ಠ‿ಠ]]
