# Editors
alias ec="emacsclient -n -t -a ''"
alias ew="env TERM=xterm-24bit emacs -nw"
alias vim=nvim
alias vi="vim -u NONE -N"

# Config
alias confd="nvim ~/.config"
alias sz='source $HOME/.zshrc'
alias reload="exec ${SHELL} -l"

# Listing dir
alias ls="ls -F"
alias la="ls -FA"
alias ll="exa --long --git"
alias lk="ls -lhSp"

# cd'ing stuff
alias ..='cd ../'
alias ...=' cd ../..'
alias cd..='cd ../'

# More helpers
alias dud="du -sh ./* | sort -h"
alias tree="tree -NC"
alias perms="stat -c '%A %a %n'"
alias cx="chmod +x"
alias c="clear"
alias -g G="| rg"
alias -g V="|& vim -"
alias pbpaste="xclip -selection clipboard -o"

# Python stuff
alias venv="python3 -m venv"
alias venvup="source env/bin/activate"
alias pip-upgrade-all="pip3 freeze --user --local | grep -v '^\-e' | cut -d = -f 1  | xargs pip3 install -U --user"
alias jpy="jupyter console --simple-prompt"

# Default programs
alias R="R -q --no-save --no-restore"
alias bc="bc -lq"
alias open="xdg-open 2>/dev/null"
alias mutt=neomutt
alias news=newsboat
alias logbook="nvim ~/Documents/logs"

# Kitty
alias kicat="kitty +kitten icat"
alias kdiff="kitty +kitten diff"
alias kgrep="kitty +kitten hyperlinked_grep"

# Docker
alias docker-ls="docker ps -a"
alias docker-rm="docker system prune -a"

# Git
g.() { git add -p "${@}" }
alias gc="git commit -m"
alias gd="git d"
alias ga="git add --all ."
alias gg="git status -s -b"

# tmux
alias mxa="tmux attach -t"
alias mxk="tmux kill-session -t"
alias mxl="tmux ls"
alias mxn="tmux new -s"

# Misc
alias nonascii="LC_CTYPE=C grep --color='auto' -n -P '[\x80-\xFF]'"
alias bat="pygmentize -g"
alias notes='rg "TODO|NOTE|FIXME"'
alias p2x1="pdfnup --nup 2x1 --landscape --suffix '2x1' --batch "
alias pdfmerge='gs -q -dNOPAUSE -dBATCH -sDEVICE=pdfwrite -sOutputFile=_merged.pdf'
alias rhelp="Rscript -e 'args <- commandArgs(TRUE); help(args[2], package=c(\"base\", \"stats\"), help_type=\"text\")' --args"
alias week='date +%V'
alias ip="dig +short myip.opendns.com @resolver1.opendns.com"
alias localip="ipconfig getifaddr en0"
alias ips="ifconfig -a | grep -o 'inet6\? \(addr:\)\?\s\?\(\(\([0-9]\+\.\)\{3\}[0-9]\+\)\|[a-fA-F0-9:]\+\)' | awk '{ sub(/inet6? (addr:)? ?/, \"\"); print }'"
alias ifactive="ifconfig | pcregrep -M -o '^[^\t:]+:([^\n]|\n\t)*status: active'"
alias path='echo -e ${PATH//:/\\n}'
alias cleanmail="rm $HOME/.mail/*/(Trash|Deleted*)/cur/*"
alias bibfind="bibtex-ls ~/Documents/notes/references.bib \
  | fzf --multi --ansi \
  | rg -o --color never '[a-z0-9\-]+$' \
  | xargs -I % sh -c 'fdfind % ~/Documents/papers' \
  | xargs -I % sh -c 'xdg-open %'"
alias bibcite="bibtex-ls ~/Documents/notes/references.bib \
  | fzf --multi --ansi \
  | rg -o --color never '[a-z0-9\-]+$' \
  | xargs -I % sh -c 'printf %'"
