function gz() {
  local origsize=$(wc -c < "$1");
  local gzipsize=$(gzip -c "$1" | wc -c);
  local ratio=$(echo "$gzipsize * 100 / $origsize" | bc -l);
  printf "orig: %d bytes\n" "$origsize";
  printf "gzip: %d bytes (%2.2f%%)\n" "$gzipsize" "$ratio";
}

function title() {
    printf '\x1b]2;%s\x07' "${1}"
}

function mkd() {
  mkdir -p "$@" && cd "$_";
}

function tre() {
  tree -aC -I '.git|node_modules|bower_components' --dirsfirst "$@" | less -FRNX;
}

function bpaste() {
  curl -F "file=@${1:--}" https://0x0.st
}

function shorten() {
  curl -F "shorten=$*" https://0x0.st
}

function fs() {
	if du -b /dev/null > /dev/null 2>&1; then
		local arg=-sbh;
	else
		local arg=-sh;
	fi
	if [[ -n "$@" ]]; then
		du $arg -- "$@";
	else
		du $arg .[^.]* ./*;
	fi;
}

function vf() {
  local files

  files=(${(f)"$(locate -Ai -0 $@ | grep -z -vE '~$' | fzf --read0 -0 -1 -m)"})

  if [[ -n $files ]]
  then
     vim -- $files
     print -l $files[1]
  fi
}

function transfer() {
    curl --progress-bar --upload-file "$1" https://transfer.sh/$(basename "$1") | tee /dev/null;
    echo
}

function rge() {
    vim \
        +'/\v'"${1/\//\\/}" \
        +':silent tabdo :1 | normal! n' \
        +':tabfirst' \
        -p $(rg "$@" | cut -d: -f1 | sort -u)
}

function despace() {
 for i in *
  do
   [ ! "$i" == "$(echo $i | tr '\ ' '_')" && mv ./"$i" ./$(echo $i | tr '\ ' '_')
  done
}

function serve() {
  local port=${1:-8000}
  local ip=$(ipconfig getifaddr en0)
  echo "Serving on ${ip}:${port} ..."
  python3 -m SimpleHTTPServer ${port}
}

function spinner() {
  while
  do
    for i in "-" "\\" "|" "/"
    do
      echo -n " $i \r\r"
      sleep .1
    done
  done
}

function timestamp() {
  echo "(date --iso-8601=seconds)"
}

function bkp() {
  cp -a "${1}" "${1}_(date +'%Y-%m-%d')"
}

function cl() {
  history --max=1 | sed -e 's/^ +//' | xclip -i -selection clipboard
  echo "Last stdout encoded to clipboard"
}

function day() {
  echo (date -j -f '%Y-%m-%d' ${1} +'%A')
}

function digga() {
  dig +nocmd "$1" any +multiline +noall +answer;
}

function snif() {
  sudo lsof -iTCP -sTCP:LISTEN -P -n
}

function wget_single() {
  wget --no-parent --timestamping --convert-links --page-requisites --no-directories --no-host-directories --span-hosts --adjust-extension ${1}
}

function enc64() {
  openssl base64 -in "${1}" | awk -v ext=(get_ext ${1}) '{ str1=str1 $0 }END{ print "background:url(data:image/"ext";base64,"str1");" }'|pbcopy
  echo "${1} encoded to clipboard"
}

function webmp4() {
  if [ -z "$(command -v ffmpeg)" ]; then
    printf "%s\n" "ffmpeg is not installed" >&2
    return 1
  fi
  while [ $# -ne 0 ]; do
    ffmpeg -i "$1" "${1%.*}.mp4"
    shift
  done
}
